"""Top-level package for python-gitea."""

from __future__ import annotations

from gitea.version import __version__

__all__ = ["__version__"]
